import React, { useState } from "react";

type InputWithDropDownProps = {
  label: string;
  value: string;
  options?: string[]; // Array of dropdown options
  activeOption?: string; // The currently active dropdown option
};

const InputWithDropDown: React.FC<InputWithDropDownProps> = ({
  label,
  value,
  options,
  activeOption,
}) => {
  const separatedWords = label
    .split(/(?=[A-Z])/)
    .map((word) => word.trim())
    .toString();

  const [openDropdown, setOpenDropdown] = useState(false);

  return (
    <div className="value-field-container">
      <label htmlFor={separatedWords} className="label">
        {label}
      </label>
      <div className="input default" id={separatedWords}>
        <input type="text" defaultValue={value} />

        <div
          className="dropdown"
          onClick={() => {
            setOpenDropdown(true);
          }}
        >
          <div className="active-option">{activeOption}</div>
          {options && openDropdown && (
            <div className="dropdown-options-list">
              {options.map((option, index) => (
                <div key={index} className={"dropdown-option"}>
                  {option}
                </div>
              ))}
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default InputWithDropDown;
